Stan Math Library: stan/math/mix/mat/functor Directory Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

functor Directory Reference

## Files
file | derivative.hpp [code]
file | finite_diff_grad_hessian.hpp [code]
file | grad_hessian.hpp [code]
file | grad_tr_mat_times_hessian.hpp [code]
file | gradient_dot_vector.hpp [code]
file | hessian.hpp [code]
file | hessian_times_vector.hpp [code]
file | partial_derivative.hpp [code]

[ Stan Home Page ] © 2011–2016, Stan Development Team.